@@ -1,6 +1,6 @@
 package Bundle::InterchangeKitchenSink;
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 1;
 
@@ -26,7 +26,7 @@ HTML::Tagset
 
 Bundle::LWP
 
-IO::Stringy
+IO::Scalar
 
 Parse::RecDescent
 
@@ -91,23 +91,15 @@ you will need these modules.
 
 =over 4
 
-=item MD5
+=item Digest::MD5
 This module is used to generate unique cache keys. If you don't have it,
 then keys will be computed with a checksum that has a very low but not
 infinitesimal chance of causing a cache conflict.
 
-=item Bundle::LWP
-Certain parts of these modules (URI::URL and MIME::Base64) are required
-for Interchange's internal HTTP server. Also, Business::UPS, for calculating
-shipping, requires this.
-
 =item Storable
 If you have this module session save speed increases by anywhere from 25-60%.
 Highly recommended for busy systems. 
 
-=item Business::UPS
-Enables lookup of shipping costs directly from www.ups.com.
-
 =item SQL::Statement
 Enables SQL-style search query statements for Interchange.
 
@@ -121,12 +113,84 @@ You will also need the appropriate DBD module, i.e. DBD::mysql to support
 B<MySQL>.
 
 =item Term::ReadKey
-Helps Term::ReadLine::Perl generate completions and editing.
+Helps Term::ReadLine::Perl generate completions and editing for makecat
+and other interactive scripts from command line.
 
 =item Term::ReadLine::Perl
 Gives you filename completion and command history in the makecat program.
 Not used otherwise.
 
+=item MIME::Base64
+Provides HTTP services for internal HTTP server and basic authentication.
+
+=item URI::URL
+Provides HTTP primitives for internal HTTP server.
+
+=item HTML::Tagset
+
+Required by Bundle::LWP.
+
+=item Bundle::LWP
+Certain parts of these modules (URI::URL and MIME::Base64) are required
+for Interchange's internal HTTP server. Also, Business::UPS, for calculating
+shipping, requires this.
+
+=item Business::UPS
+Enables lookup of shipping costs directly from www.ups.com. Requires Bundle::LWP.
+
+=item IO::Scalar
+Used for Spreadsheet::*Excel.
+
+=item Parse::RecDescent
+
+Used for Spreadsheet::*Excel.
+
+=item OLE::Storage_Lite
+
+Used for Spreadsheet::*Excel.
+
+=item Image::Size
+
+Needed for [image ...] tag.
+
+=item Tie::ShadowHash
+
+Needed for pre-fork mode of Interchange, prevents permanent write of configuration.
+
+=item Spreadsheet::ParseExcel
+Allows upload of XLS spreadsheets for database import in the UI.
+
+=item Spreadsheet::WriteExcel
+Allows output of XLS spreadsheets for database export in the UI.
+
+=item Archive::Tar
+Only needed for supplementary UserTag definitions.
+
+=item Archive::Zip
+Only needed for supplementary UserTag definitions.
+
+=item Compress::Zlib
+Only needed for supplementary UserTag definitions.
+
+=item Crypt::SSLeay
+
+Payment interface links via HTTPS/SSL.
+
+=item Mail::Sendmail
+
+Needed for internal mailing methods not using sendmail.
+
+=item SOAP::Lite
+
+Only needed when employing SOAP.
+
+=item Tie::Watch
+
+Allows tied configuration values that execute subroutines on access or set.
+
+=item Time::HiRes
+
+Needed for some Intranet functions.
 
 =head1 AUTHOR
 
